@@ -649,6 +649,10 @@ def predict_goals(pbp):
     for strength, df_dict in big_dict.items():
         
         df = df_dict['data']
+
+        if df.empty:
+
+            continue
         
         model = df_dict['model']
         
